# Multidirectional Leg Asymmetry Assessment in Sport

Jennifer Hewit, MSc, CSCS, \[1\] John Cronin, PhD, \[1,2\] and Patria Hume, PhD \[1\]

1Sport Performance Research Institute New Zealand, AUT University, Auckland, New Zealand; and 2School of
Exercise, Biomedical and Health Sciences, Edith Cowan University, Joondalup, Western Australia, Australia

S U M M A R Y

LEG ASYMMETRY ASSESSMENTS

IN ATHLETES CAN PROVIDE VALU
ABLE PROGNOSTIC/DIAGNOSTIC

INFORMATION. THIS BRIEF REVIEW

PROVIDES INFORMATION ON

OUTCOME MEASURES THAT

DESCRIBE LIMB ASYMMETRY

(POWER, FORCE, AND DISTANCE/
HEIGHT JUMPED), RELIABILITY OF

SINGLE-LIMB MULTIDIRECTIONAL

ASSESSMENTS, AND EXPECTED

MAGNITUDES OF ASYMMETRY IN

NONINJURED AND INJURED ATH
LETES. THE RELIABILITY (COEFFI
CIENT OF VARIATION = 2.8–40%,

INTRACLASS CORRELATION

COEFFICIENT = 0.80–1.0) OF

SINGLE-LIMB MULTIDIRECTIONAL

LEG ASSESSMENTS ALLOWS

STRENGTH AND CONDITIONING

COACHES TO USE THESE

ASSESSMENTS TO DETECT

ASYMMETRIES IN ATHLETES,

WHICH MAY PROVIDE INFORMA
TION ABOUT THE POTENTIAL FOR

INJURY AND HENCE GUIDE INJURY

PREVENTION PROGRAMMING.

EXPECTED MAGNITUDES OF LIMB

ASYMMETRY ARE LESS THAN 15%

FOR NONINJURED ATHLETES.

INTRODUCTION

eg power in sport is commonly
assessed using a vertical jump

## L assessment task and subsequent

derivations. The combination of the simplistic testing procedures and equipment

(e.g., contact mat, high-speed video,
Vertec apparatus, etc.), supposedly high
specificity to sport, and reliable results
associated with a vertical jump assessment task make it a popular test among
coaches and strength training professionals. Many movements (e.g. running,
leaping, jumping, cutting, etc.) a player is
required to perform throughout a competition occur not only in a vertical
direction but also in horizontal and/or
lateral directions. Using only the vertical
jump to create a profile of a player who
also performs movement tasks in horizontal and/or lateral directions during
competition is flawed (5). The assumption that leg power is the same across
all 3 directions (vertical, horizontal, and
lateral) is most likely incorrect (11,13).
Therefore, the assessment tasks that
target each of these directions are needed
to create an accurate player profile.

Multidirectional leg-power assessments
provide coaches and strength training
professionals with data that can be used
for monitoring and assessment, baseline
comparative values when athletes are
injured, or threshold values for predictors of performance (e.g., minimum
standards). Of interest in this article is
the use of single-limb assessments to
detect limb asymmetries, which may
provide information about the potential
for injury and hence guide injury prevention or off-season programming.
This brief review provides information
on outcome measures that describe limb
asymmetry and the reliability of singlelimb multidirectional assessments. The

determinants of these asymmetries can
be many (e.g., hereditary, injury, mechanical, physiological, anatomical, etc.)
and are outside the focus of this article.

Furthermore, it should be noted that
asymmetry between limbs can be a naturally occurring phenomenon reflecting
the demands of the specific sport. For
example, the dominant arm of a baseball
pitcher or tennis player will likely have
greater muscle mass and strength and
power outputs when compared with the
contralateral arm. As such, substantial
asymmetries are expected; however, the
magnitude of these asymmetries in
noninjured players for specific sports
should be documented so that normative ranges of asymmetry in players can
be identified. This provides another
focus of this article.

OUTCOME MEASURES THAT
DESCRIBE LEG ASYMMETRY
Dynamic directional changes in sport
(vertical, horizontal, or lateral) are not
always performed using a bilateral takeoff or landing. When a single-leg is used
to propel the body and absorb the
intense impact forces and torques incurred upon landing, any muscle imbalances could affect the success of the
movement task by placing increased
strain on the weaker leg (8). Therefore,
leg power asymmetry is commonly
assessed using various forms of singleleg jumping tasks because of the relative
ease of administration and cost

K E Y W O R D S :
asymmetry; leg power; assessment

82 VOLUME 34 | NUMBER 1 | FEBRUARY 2012 Copyright � National Strength and Conditioning Association

effectiveness of testing and analysis.
When the percent difference between
legs is calculated, a measure of limb
asymmetry is produced (e.g., average
symmetry index (ASI) = \[1 2 dominant
leg/nondominant leg\] 3 100). Researchers have presented absolute values, but these do not clearly indicate the
direction of the change, only that there
is a difference. Strength and conditioning coaches should provide positive or
negative ASI values so that it is clear that
a positive percentage change indicates
that the noninjured limb is better than
the injured limb, for example.

Leg asymmetry magnitudes can be
calculated from jump distance and/or
jump height measurements (e.g., tape
measure, Vertec \[Gill Athletics, Champaign, IL\], etc.) or if the technology is
available, a force plate (e.g., peak force
and peak power). Measures such as
jump height and distance may be less
sensitive for limb asymmetry than power
output. For example, Meylan et al. (14)
reported different ASI magnitudes for
distance (3.9–6.0%), force (0.4–7.6%),
and power (2.1–9.3%) for the same
jumps across different directions. Although all 3 variables provided valuable
information regarding player leg asymmetries, those calculated from peak
power identified a greater number of
players with asymmetry magnitudes
above 10% than both peak force and
jump distance/height variables. With
power being a product of both force
and velocity, it may be that this measure
can better detect differences between the
limbs. Velocity may be the limiting factor
for an athlete, so velocity of movement
would become the focus of training.
Using a measure such as power output in
conjunction with force output could
help with programming. To the knowledge of the authors, no study to date has
assessed the sensitivity of force, power,
and distance as measures to detect limb

asymmetry.

RELIABILITY OF SINGLE-LIMB
MULTIDIRECTIONAL LEG POWER

ASSESSMENTS
Until recently, there has been limited research addressing the reliability of multidirectional leg power. A

straightforward approach to creating
multidirectional assessments is to take
the vertical jump task (known to be
reliable) and perform it across the
horizontal and lateral directions.
Individual player’s directional strengths
and weaknesses can be identified
through this approach and can provide
direction for programming. Very little
research has assessed the reliability of
single-leg countermovement jumps
performed in the vertical, horizontal,
and lateral directions (13). Given the
paucity of literature in this area, Table 1
presents studies that have investigated
the reliability of double-leg and
single-leg jumps in various directions.
Although there are no preset standards
as to what is and is not acceptable as
a reliable measure, Walmsley and
Amell (20) suggested that intraclass
correlation coefficient (ICC) values
above 0.75 may be considered reliable,
and this index should be at least 0.90
for most clinical applications (20). An
analytical goal of the coefficient of
variation percentage (CV%) being 10%
or below has been chosen arbitrarily by
some scientists, but the merits of this
value are the source of conjecture (1). It
would seem that all variables detailed
in Table 2 had relative consistency
(ICC) greater than the 0.75 thresholds.
Double-leg jumps appear to have
greater consistency, whereas jump
performance without arms affixed to
the hip seems to be less consistent (i.e.,
less reliable). With regards to absolute
consistency (CV%), no observable
trend was apparent. In the only study
(13) that compared reliability of 3
jumps, the jump measures across all
the 3 directions were highly reliable
(ICCs ranging from 0.82 to 0.98, CV%s
ranging from 1.1 to 7.2%) with the
greatest reliability associated with the
horizontal direction (see Table 2).

Shared variances between single-leg and
double-leg vertical, horizontal, and lateral countermovement jumps reported
in 3 studies (5,6,10) ranged from 13 to
62%. This suggests that testing athletes
across 3 directions measures relatively
independent leg-power qualities. Therefore, when assessing the leg-power

capability of players who consistently
perform rapid and explosive multidirectional movements in competition, the
inclusion of an assessment targeting all
the 3 directions is desirable.

MAGNITUDES OF LEG POWER

ASYMMETRY IN INJURED AND
NON-INJURED ATHLETES

Strength and conditioning coaches
need to know the expected magnitude
of asymmetry in noninjured players.
Maulder et al. (11) reported mean
asymmetries of 1.1% for the horizontal
countermovement jump and no difference for the vertical countermovement
jump distance for 18 male sportsmen.
Studying the ASI magnitudes of 30
noninjured team sport athletes (soccer,
basketball, field hockey, and rugby),
Meylan et al. (14) cited mean ASIs in
height and distance for the vertical,
horizontal, and lateral jumps ranging
from 2.6 to 6.0%. This study also
reported the mean ASIs of a variety
of kinetic variables (eccentric and
concentric peak force and powers),
ranging from 0.4% (horizontal concentric peak force) to 9.3% (lateral concentric peak power). With regards to
kinetic variables across the 3 jump
directions, mean ASIs ranging from
3.0% (vertical concentric peak force) to
11.4% (horizontal concentric peak
power) have been observed.

There is no specific magnitude of
asymmetry that has been identified in
the literature as a definitive threshold
separating injured and noninjured players or the potential for injury. However,
it would seem magnitudes of 15% or
more are often associated with players
who have recently sustained an injury,
whereas magnitudes below 10% are
typically reported in noninjured populations (7,11,14,15). Therefore, an
asymmetry threshold of 10–15% or
more is thought to place additional
strain on the weaker leg, compromising
the player’s performance and predisposing the athlete to various injuries
(8,12,16,17). As gender and the physical
requirements of the sport (e.g., positional demands) are likely to contribute
to muscle development and imbalances, such a threshold can be used as

Strength and Conditioning Journal | \<www.nsca-lift.org> 83

Table 1

Acyclic single-leg and double-leg direction-specific jumping task reliability for a selection of published studies.

| Study                        | Participants                                                       | Task                                                             | Mean6SD(cm)                                                                                                                      | ICC                                                              | CV%                                                              |
| ---------------------------- | ------------------------------------------------------------------ | ---------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------- | ---------------------------------------------------------------- |
| Vertical jumping direction   |                                                                    |                                                                  |                                                                                                                                  |                                                                  |                                                                  |
| Brosky et al. (3)            | 15 men 15–39 months after<br>unilateral ACL reconstruction         | SL CMJ with AM                                                   | Noninjured: 39.6 6 6.5                                                                                                           | 0.86–0.97                                                        | 16.4<br>18.2                                                     |
| Brosky et al. (3)            | 15 men 15–39 months after<br>unilateral ACL reconstruction         | SL CMJ with AM                                                   | Injured: 40.6 6 7.4                                                                                                              | Injured: 40.6 6 7.4                                              | Injured: 40.6 6 7.4                                              |
| Hopper et al. (9)            | 13 men and 6 women 12 weeks after<br>unilateral ACL reconstruction | SL CMJ without AM                                                | Non-injured: 38.0 6 4.0                                                                                                          | 0.92                                                             | 10.5<br>17.6                                                     |
| Hopper et al. (9)            | 13 men and 6 women 12 weeks after<br>unilateral ACL reconstruction | SL CMJ without AM                                                | Injured: 34.0 6 6.0                                                                                                              | Injured: 34.0 6 6.0                                              | Injured: 34.0 6 6.0                                              |
| Meylan et al. (13)           | 44 male, 36 female recreational athletes                           | SL CMJ without AM                                                | Males: 23.2 6 3.7                                                                                                                | 0.96                                                             | 6.7                                                              |
| Meylan et al. (13)           | 44 male, 36 female recreational athletes                           | SL CMJ without AM                                                | Females: 16.9 6 2.9                                                                                                              | 0.91                                                             | 7.2                                                              |
| Maulder et al. (11)          | 18 male recreational athletes                                      | SL SJ without AM                                                 | Dominant: 15.7 6 4.0                                                                                                             | 0.82–0.86                                                        | 3.3–4.4                                                          |
| Maulder et al. (11)          | 18 male recreational athletes                                      | SL SJ without AM                                                 | Non-dominant: 15.8 6 3.3                                                                                                         | Non-dominant: 15.8 6 3.3                                         | Non-dominant: 15.8 6 3.3                                         |
| Maulder et al. (11)          | 18 male recreational athletes                                      | SL CMJ without AM                                                | Dominant: 18.4 6 4.2                                                                                                             | 0.86–0.95                                                        | 3.3–4.1                                                          |
| Maulder et al. (11)          | 18 male recreational athletes                                      | SL CMJ without AM                                                | Non-dominant: 18.8 6 3.7                                                                                                         | Non-dominant: 18.8 6 3.7                                         | Non-dominant: 18.8 6 3.7                                         |
| Markovic et al. (10)         | 93 male recreational athletes                                      | Stand & reach DL<br>CMJ with AM                                  | 55.2 6 6.1                                                                                                                       | 0.96                                                             | 3.0                                                              |
| Markovic et al. (10)         | 93 male recreational athletes                                      | DL SJ without AM                                                 | 32.7 6 4.2                                                                                                                       | 0.97                                                             | 3.3                                                              |
| Markovic et al. (10)         | 93 male recreational athletes                                      | DL CMJ without AM                                                | 35.3 6 4.5                                                                                                                       | 0.98                                                             | 2.8                                                              |
| Chamari et al. (4)           | 15 male elite soccer players                                       | DL SJ without AM                                                 | 52.8 6 5.5                                                                                                                       | —                                                                | 10.4                                                             |
| Chamari et al. (4)           | 15 male elite soccer players                                       | DL CMJ with AM                                                   | 62.4 6 5.6                                                                                                                       |                                                                  | 9.0                                                              |
| Horizontal jumping direction |                                                                    |                                                                  |                                                                                                                                  |                                                                  |                                                                  |
| Bolga and Keskula (2)        | 5 men, 15 women                                                    | SL CMJ with AM                                                   | 137.1 6 22.1                                                                                                                     | 0.96                                                             | 16.1                                                             |
| Brosky et al. (3)            | 15 men 15–39 months after<br>unilateral ACL reconstruction         | SL CMJ with AM                                                   | Noninjured: 173.5 6 21.1                                                                                                         | 0.86–0.97                                                        | 12.2<br>10.7                                                     |
| Brosky et al. (3)            | 15 men 15–39 months after<br>unilateral ACL reconstruction         | SL CMJ with AM                                                   | Injured: 173.1 6 18.5                                                                                                            | Injured: 173.1 6 18.5                                            | Injured: 173.1 6 18.5                                            |
| Markovic et al. (10)         | 93 male recreational athletes                                      | DL CMJ with AM                                                   | 251.5 6 15.0                                                                                                                     | 0.95                                                             | 2.4                                                              |
| Greenberger and Paterno (6)  | 20 noninjured participants                                         | SL CMJ without AM                                                | —                                                                                                                                | 0.92–0.96                                                        | —                                                                |
| Paterno and Greenberger (18) | 7 men and 13 women noninjured                                      | SL CMJ without AM                                                | Non-injured: dominant: 150.6 6 23.4;<br>nondominant: 147.6 6 20.4<br>Injured: injured: 146.0 6 33.1;<br>noninjured: 167.9 6 25.1 | 0.92–0.96                                                        | 13.8–15.5<br>14.9–22.7                                           |
| Paterno and Greenberger (18) | 8 men and 5 women ACL reconstructed<br>20–52 weeks after surgery   | 8 men and 5 women ACL reconstructed<br>20–52 weeks after surgery | 8 men and 5 women ACL reconstructed<br>20–52 weeks after surgery                                                                 | 8 men and 5 women ACL reconstructed<br>20–52 weeks after surgery | 8 men and 5 women ACL reconstructed<br>20–52 weeks after surgery |

ACL = anterior cruciate ligament; AM = arm movement; CMJ = countermovement jump; DL = double-leg; SJ = squat jump; SL = single-leg.

asymmetries across multiple directions
to gain insight into individual player’s
strength and weaknesses.

Leg asymmetries are most usually
obtained from velocity, force, or power
measures. Leg-power asymmetry is
possibly the most reliable and of
greatest prognostic value. Given force
plates are not readily available to many
strength and conditioning coaches,
jump distance and height should be
used to evaluate leg asymmetry. A
threshold of 15% can be used to
identify players who may be at risk of
incurring a lower limb injury and
therefore requiring additional training
focused on correcting the limb asymmetry in the appropriate manner. Once
an asymmetry above the considered
threshold of 15% has been identified in
an athlete, it may be beneficial to
include additional assessments (i.e.,
balance—proprioception, range of motion of joints, etc.) to try to determine
the mechanism of injury. Additionally,
introducing a physical therapist at this
stage may be a good practice (particularly if the asymmetry is caused by
injury) because they may have a more
refined sense of movement dysfunction
and may be more attuned to the key
indicators of specific symptoms associated with such dysfunctions.

Jennifer Hewit

is a PhD student

in Biomechanics
and Strength and
Conditioning at
AUT University.

John Cronin is
a professor in
Strength and Conditioning at AUT
University and
holds an Adjunct
Professorial Position at Edith
Cowan University.

| Player<br>A | SLCMjumpdirection<br>rankings | Col3       | Col4     |
| ----------- | ----------------------------- | ---------- | -------- |
| Player<br>A | Lateral                       | Horizontal | Vertical |
| Player<br>A | 1                             | 11         | 13       |
| B           | 2                             | 21         | 17       |
| C           | 3                             | 6          | 9        |
| D           | 4                             | 10         | 18       |

a guideline for injury prevention, programming, and readiness to return to
play but not as a definitive predictor or
indicator of injury.

Paterno et al. (17) compared leg
asymmetry of anterior cruciate ligament rehabilitated athletes with that of
noninjured collegiate athletes when
performing a single-leg drop jump for
height. Asymmetry of 15% or more
was observed in the rehabilitated subjects up to 2 years after surgery, which
reportedly placed them at a greater risk
of injury to either leg in the future.
Similar results were found in a study
conducted by Schiltz et al. (19) where
single-leg drop jump leg asymmetry
was compared among junior-level
(noninjured), recreational (noninjured),
and professional-level basketball players (with and without previous knee
injury). Although the 2 noninjured
groups had mean asymmetry magnitude lower than 5% for jump height,
the mixed group of professional players
had asymmetry magnitude of 12 6
7.9%. Professional players with previous knee injuries had asymmetry
magnitude averaging 18.4 6 7.8%,
whereas players without previous
injury had mean asymmetry magnitude
of 8.9 6 6.1%.

Players presenting leg asymmetries
greater than 15% in any direction
may not necessarily incur an injury,
whereas those players with asymmetries below the threshold are certainly
not exempt from injury. Regardless of

the threshold used, symmetry between
legs is thought desirable by coaches,
trainers, clinicians, and players, and
minimizing imbalances between legs is
a goal within many training programs.

MULTIDIRECTIONAL LEG POWER

ASYMMETRY

It is important for professionals to
incorporate assessments that will provide the most accurate, dependable,
and relevant information (without
overlap) regarding player performance
for the particular sport of interest.
Shared variance between countermovement jumps performed in the
vertical, horizontal, and lateral planes
is moderate at best (11,12,16), with
assessments being relatively independent of each other. Strength and
conditioning coaches working with
athletes involved in multidirectional
movements may find that a multidirectional leg power profile can help drive
subsequent programming. The prognostic/diagnostic value of a test of leg
asymmetry seems to be dependent
on not only the specificity (face
validity) of the test but also the
reliability. Although data in literature
are often presented as means and
standard deviations for a group of
athletes (Table 1), the presentation of
ASI data as an average response (mean
and standard deviation) often masks
critical individual responses to testing.
Individualization of programming is
fundamental to an athlete’s development and needs to be kept in mind. An
example of 4 players of a netball squad
(see Table 2) represents the notion of
individual responders and how asymmetry in one direction is not indicative
of all directions.

Validation of limb asymmetry thresholds and research on movements and
variables that provide the most valuable
information to clinicians and strength
and conditioning coaches is needed.

SUMMARY

Players’ movements in sport involve
multiple directions, so jump assessments are conducted in vertical, horizontal, and lateral directions. Jump
assessments can be used to assess leg

Strength and Conditioning Journal | \<www.nsca-lift.org> 85

### Multidirectional Leg Asymmetry Assessment

Patria Hume is
a professor in
Human Performance (Sport Biomechanics) at
AUT University.

REFERENCES

1. Atkinson G and Nevill AM. Statistical

methods for assessing measurement error
(reliability) in variables relevant to sports
medicine. Sports Med 26: 217–238, 1998.

2. Bolga L and Keskula D. Reliability of lower
   extremity functional performance tests.
   J Orthop Sports Phys Ther 26: 138–142,

1.

1. Brosky J, Nitz A, Malone T, Caborn D, and
   Rayens M. Intrarater reliability of selected
   clinical outcome measures following
   anterior cruciate ligament reconstruction.
   J Orthop Sports Phys Ther 29: 39–48,

1.

1. Chamari K, Chaouachi A, Hambli M,
   Kaouech F, Wisloff U, and Castagna C. The
   five-jump test for distance as a field test to
   assess lower limb explosive power in soccer
   players. J Strength Cond Res 22: 944, 2008.

1. Cronin J and Hansen K. Strength and
   power predictors of sports speed.
   J Strength Cond Res 19: 349–357, 2005.

1. Greenberger H and Paterno M. The testretest reliability of a one-legged hop for

distance in healthy young adults. J Orthop
Sports Phys Ther 19: 62, 1994.

7. Hickey K, Quatman C, Myer G, Ford K,
   Brosky J, and Hewett T. Methodological
   report: Dynamic field tests used in an NFL
   combine setting to identify lower extremity
   functional asymmetries. J Strength Cond
   Res 23: 2500–2506, 2009.

1. Hoffman J, Ratamess N, Klatt M,

Faigenbaum A, and Kang J. Do bilateral
power deficits influence direction-specific
movement patterns? Res Sports Med 15:

125–132, 2007.

9. Hopper D, Goh S, Wentworth L, Chan D,
   Chau J, Wootton G, Strauss G, and Boyle J.
   Test-retest reliability of knee rating scales
   and functional hop tests one year following
   anterior cruciate ligament reconstruction.
   Phys Ther Sport 3: 10–18, 2002.

1. Markovic G, Dizdar D, Jukic I, and
   Cardinale M. Reliability and factorial
   validity of squat and countermovement
   jump tests. J Strength Cond Res 18:

551–555, 2004.

11. Maulder P and Cronin J. Horizontal and

vertical jump assessment: Reliability,
symmetry, discriminative and predictive
ability. Phys Ther Sport 6: 74–82, 2005.

12. McElveen M, Riemann B, and Davies G.

Bilateral comparison of propulsion
mechanics during single-leg vertical
jumping. J Strength Cond Res 24: 375–

382, 2010.

13. Meylan C, McMaster T, Cronin J,
    Mohammad N, Rogers C, and Deklerk M.
    Single-leg lateral, horizontal, and vertical
    jump assessment: Reliability,
    interrelationships, and ability to predict

sprint and change-of-direction
performance. J Strength Cond Res 23:

1140–1147, 2009.

14. Meylan C, Nosaka K, Green J, and Cronin J.
    Temporal and kinetic analysis of unilateral
    jumping in the vertical, horizontal, and
    lateral directions. J Sports Sci 28: 545–

554, 2010.

15. Newton R, Gerber A, Nimphius S, Shim J,
    Doan B, Robertson M, Pearson D, Craig B,
    Hakkinen K, and Kraemer W.

Determination of functional strength

imbalance of the lower extremities.

J Strength Cond Res 20: 971–977, 2006.

16. Noyes F, Barber S, and Mangine R.
    Abnormal lower limb symmetry determined
    by functional hop tests after anterior
    cruciate ligament rupture. Am J Sports
    Med 19: 513–518, 1991.

01. Paterno M, Ford K, Myer G, Heyl R, and
    Hewett T. Limb asymmetries in landing and
    jumping 2 years following anterior cruciate
    ligament reconstruction. Clin J Sports Med

17: 258–262, 2007.

18. Paterno M and Greenberger H. The testretest reliability of a single-leg hop for
    distance in young adults with and without

ACL reconstruction. Isokinetics Exercise

Sci 6: 1–6, 1996.

19. Schiltz M, Lehance C, Maquet D, Bury T,
    Crierlaard J, and Croisier J. Explosive strength
    imbalances in professional basketball players.
    J Athletic Train 44: 39–47, 2009.

01. Walmsley RP and Amell TK. The
    application and interpretation of intraclass
    correlations in the assessment of reliability
    in isokinetic dynamometry. Isokinetics
    Exercise Sci 6: 117–124, 1996.

86 VOLUME 34 | NUMBER 1 | FEBRUARY 2012
